//***************************************************************************
// Ces applets viennent en complment du livre :
//
//  		VIE ARTIFICIELLE
//      O la biologie rencontre l'informatique
//		Illustr en Java
//            Jean-Philippe Rennard
//           	  Vuibert 2002
//===========================================================================
//  Automates cellulaires autoreproducteurs  (Vuibert)
//    v:0.1 07/09/2002
//
//  This program demonstrates a celular automata devoted to self-reproduction
//  It is based on :
//      Morita K., Imai K.,  A Simple Self-Reproducing Cellular Automaton
//      whith Shape-Encoding Mechanism , Artificial Life V, Proceedings of
//      fifth International Workshop on the Synthesis and Simulation of Living
//      Systems, MIT Press, Cambridge, 1997.
//      http://kepi.ke.sys.hiroshima-u.ac.jp/projects/ca/sr/
//
//    This program is free software; you can redistribute it and/or
//    modify it under the terms of the GNU General Public License
//    as published by the Free Software Foundation.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//***************************************************************************
package ar;

import java.awt.*;
import vabase.*;

/** Classe automate cellulaire */
public class Cac extends Cprocess {
  static final int MAXNBVOISINS=5;
  static final int MAXNBETATS=12;
  static final int TAILLE_DEFAUT=50;
  static final byte VALREPOS=(byte)'#';

  // Figures
  static final int VERS1=0;
  static final int VERS3=1;
  static final int VERS7=2;
  static final int VERSS=3;
  static final int BOUCLE1=4;
  static final int BOUCLE2s=5;


  static final byte FIGURES[][][]=
  {
    { // Le plus petit vers autoreproducteur
      {4,1},
      {'B'},
      {'^'},
      {'S'},
      {'^'}
    },
    { // 3 vers
      {5,4},
      {'>','S','>','L'},
      {'#','#','#','#'},
      {'>','S','#','#'},
      {'#','#','#','#'},
      {'>','L','>','R'}
    },
    { // Un vers en forme de 7
      {6,5},
      {'R','<','S','<','B'},
      {'#','#','#','#','^'},
      {'#','#','#','>','S'},
      {'#','#','>','L','#'},
      {'#','#','R','#','#'},
      {'#','#','^','#','#'}
    },
    { // Un vers en forme de S
      {9,6},
      {'#','B','>','S','>','L'},
      {'S','^','#','#','#','#'},
      {'^','#','#','#','#','#'},
      {'S','<','#','#','#','#'},
      {'#','S','<','S','<','#'},
      {'#','#','#','#','S','<'},
      {'#','#','#','#','#','S'},
      {'#','#','#','#','S','^'},
      {'>','R','>','S','^','#'}
    },
    { // La plus petite boucle
      {3,3},
      {'S','<','S'},
      {'v','#','^'},
      {'@','>','S'}
    },
    { // Une boucle complexe
      {10,8},
      {'#','#','#','S','<','S','#','#'},
      {'#','#','#','v','#','^','S','<'},
      {'#','#','#','S','v','#','#','S'},
      {'S','<','S','#','S','#','#','^'},
      {'v','#','^','S','<','#','>','S'},
      {'S','#','#','#','#','>','S','#'},
      {'>','S','v','#','#','S','#','#'},
      {'#','#','S','#','S','^','#','#'},
      {'#','#','v','#','^','#','#','#'},
      {'#','#','@','>','S','#','#','#'}

    }
  };
  /** Pointeur sur l'interface utilisateur */
  private arUI appUI;
  /** Grille de travail 1 */
  private Cgrille grille1;
  /** Grille de travail 2 */
  private Cgrille grille2;
  /** Grille courante (rfrence) */
  Cgrille grille;
  /** Table lookup */
  private String lookup[][];
  /** Nombre d'tats */
  byte nbEtats;
  /** Vue */
  vueAr arVue;

  /** Constructeur : cre les grilles */
  public Cac(arUI ui, int nbcol, int nblig) {
    super(ui);
    appUI=ui;
    arVue=new vueAr(this, Color.black, Color.white);
    vue=(Cvue)arVue;
    setGrille(nbcol, nblig);
    setRegles();
  }
  /** Modification taille */
  public void setTaille(int nbcol, int nblig) {
    setGrille(nbcol, nblig);
    initVue();
  }
  /** Appel construction de la table de recherche */
  public boolean setRegles() {
    creeLookup();
    return true;
  }

  /** Cration des grilles */
  private void setGrille(int nbcol, int nblig) {
    grille1 =new Cgrille(this, nbcol, nblig);
    grille2 =new Cgrille(this, nbcol, nblig);
    grille=grille1;
    generation=0;
  }
  /** Construit table lookup (rgles) */
  private void creeLookup() {
    lookup=null;
    lookup=Cregles.regles;
  }
  /** Vide l'automate */
  public void effaceGrille() {
    grille.videGrille();
    generation=0;
    grille.affGrille();
    arVue.repaint();
  }
  /** Initialisation/MAJ de la vue */
  public void initVue() {
    arVue.setNewTaille();
  }
  /** Gnration suivante */
  public void geneSuiv() {
  // switch grille courante
    Cgrille grBuff;
    grBuff=(grille==grille1 ? grille2 : grille1);
    for(int i=0;i<grille.getNbCellHoriz();i++) {
      for(int j=0;j<grille.getNbCellVertic();j++) {
        String s=grille.getNbVoisins(i,j);
        int bot=0;
        int up=2203;      // Nombre de rgles
        int c;
        while((up-bot)>1 && !(s.equals(lookup[up][0])) &&
                                        !(s.equals(lookup[bot][0]))) {
          c=(up+bot)/2;
          if(s.compareTo(lookup[c][0])<0)
            up=c;
          else
            bot=c;
        }
        if(s.equals(lookup[bot][0]))
          grBuff.setCellule(i,j,(byte)lookup[bot][1].charAt(0));
        else if(s.equals(lookup[up][0]))
          grBuff.setCellule(i,j,(byte)lookup[up][1].charAt(0));
        else
          grBuff.setCellule(i,j,VALREPOS);
      }
    }
    generation++;
    grille=grBuff;
    grille.affGrille();
    arVue.repaint();
    appUI.affGeneration();
  }
  /** Ajoute une figure */
  public void ajoutFigure(int fig) {
    generation=0;
    grille.setFigure(fig);
    grille.affGrille();
    arVue.repaint();
  }
}
