//***************************************************************************
// Ces applets viennent en complment du livre :
//
//  		VIE ARTIFICIELLE
//      O la biologie rencontre l'informatique
//		Illustr en Java
//            Jean-Philippe Rennard
//           	  Vuibert 2002
//===========================================================================
//  Automates cellulaires autoreproducteurs  (Vuibert)
//    v:0.1 07/09/2002
//
//  This program demonstrates a celular automata devoted to self-reproduction
//  It is based on :
//      Morita K., Imai K.,  A Simple Self-Reproducing Cellular Automaton
//      whith Shape-Encoding Mechanism , Artificial Life V, Proceedings of
//      fifth International Workshop on the Synthesis and Simulation of Living
//      Systems, MIT Press, Cambridge, 1997.
//      http://kepi.ke.sys.hiroshima-u.ac.jp/projects/ca/sr/
//
//    This program is free software; you can redistribute it and/or
//    modify it under the terms of the GNU General Public License
//    as published by the Free Software Foundation.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//***************************************************************************
package ar;

/** Cette classe gre une grille  2 dimensions */
public class Cgrille {
  static final int NORD=1;
  static final int NORDEST=2;
  static final int EST=3;
  static final int SUDEST=4;
  static final int SUD=5;
  static final int SUDOUEST=6;
  static final int OUEST=7;
  static final int NORDOUEST=8;

  /** pointeur sur l'automate cellulaire */
  private Cac acPere;
  /** Table des cellules */
  private byte cellule[][];
  /** Paramtres de dimension */
  private int tailleX, tailleY;

  /** Constructeur de la grille */
  public Cgrille(Cac ap, int x, int y) {
    acPere=ap;
    cellule=new byte[x][y];
    tailleX=x;
    tailleY=y;
    videGrille();
  }
  /** Renvoit nb cellules horizontales */
  public int getNbCellHoriz() {
    return(tailleX);
  }
  /** Renvoit nb cellules verticales */
  public int getNbCellVertic() {
    return(tailleY);
  }
  /** Vide la grille (tout  l'tat repos) */
  public void videGrille() {
    for(int x=0;x<tailleX;x++)
      for(int y=0;y<tailleY;y++)
        setCellule(x, y, (byte)Cac.VALREPOS);
  }
  /** Passe une cellule  l'tat donn */
  public void setCellule(int x, int y, byte etat) {
    cellule[x][y]=etat;
  }
  /** Renvoit tat de la cellule */
  public byte getCellule(int x, int y) {
    return(cellule[x][y]);
  }
  /** Renvoit tat cellule voisine selon position */
  private byte getVoisin(int x, int y, int pos) {
    switch(pos) {
      case NORD:
        return(cellule[x][(tailleY+y-1)%tailleY]);
      case NORDEST:
        return(cellule[(x+1)%tailleX][(tailleY+y-1)%tailleY]);
      case EST:
        return(cellule[(x+1)%tailleX][y]);
      case SUDEST:
        return(cellule[(x+1)%tailleX][(tailleY+y+1)%tailleY]);
      case SUD:
        return(cellule[x][(tailleY+y+1)%tailleY]);
      case SUDOUEST:
        return(cellule[(tailleX+x-1)%tailleX][(tailleY+y+1)%tailleY]);
      case OUEST:
        return(cellule[(tailleX+x-1)%tailleX][y]);
      case NORDOUEST:
        return(cellule[(tailleX+x-1)%tailleX][(tailleY+y-1)%tailleY]);
      default:
        return(cellule[x][y]);
    }
  }
  /** construit la chane de voisinage */
  public String getNbVoisins(int x, int y) {
    String s="";
    s += (char)getCellule(x,y);
    s +=  (char)getVoisin(x,y,NORD);
    s +=  (char)getVoisin(x,y,EST);
    s +=  (char)getVoisin(x,y,SUD);
    s +=  (char)getVoisin(x,y,OUEST);
    return s;
  }
  /** Affiche l'ensemble des cellules */
  public void affGrille() {
    acPere.arVue.peintFond();
    for(int x=0;x<tailleX;x++)
      for(int y=0;y<tailleY;y++)
            affCell(x,y);
  }
  /** Affiche une cellule */
  public void affCell(int x, int y) {
    acPere.arVue.affCell(x, y, cellule[x][y]);
  }
  /** Ajoute une figure */
  public void setFigure(int fig) {
    videGrille();
    int l=Cac.FIGURES[fig][0][0];
    int c=Cac.FIGURES[fig][0][1];
    int posx=tailleX/2-(c/2);
    int posy=tailleY/2-(l/2);
    for(int i=1;i<=l;i++) {
      for(int j=0;j<c;j++)
        cellule[posx+j][posy+i]=Cac.FIGURES[fig][i][j];
    }
  }
}
