//***************************************************************************
// Ces applets viennent en complment du livre :
//
//  		VIE ARTIFICIELLE
//      O la biologie rencontre l'informatique
//		Illustr en Java
//            Jean-Philippe Rennard
//           	  Vuibert 2002
//===========================================================================
//  Automates cellulaires autoreproducteurs  (Vuibert)
//    v:0.1 07/09/2002
//
//  This program demonstrates a celular automata devoted to self-reproduction
//  It is based on :
//      Morita K., Imai K.,  A Simple Self-Reproducing Cellular Automaton
//      whith Shape-Encoding Mechanism , Artificial Life V, Proceedings of
//      fifth International Workshop on the Synthesis and Simulation of Living
//      Systems, MIT Press, Cambridge, 1997.
//      http://kepi.ke.sys.hiroshima-u.ac.jp/projects/ca/sr/
//
//    This program is free software; you can redistribute it and/or
//    modify it under the terms of the GNU General Public License
//    as published by the Free Software Foundation.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//***************************************************************************
package ar;

/** Cette classe contient les rgles de Morita et Imai */
public class Cregles {
  /** Table des tats */
  static char etats[]=
    {
      '#',
      '^',
      '>',
      'v',
      '<',
      'S',
      'L',
      'R',
      'B',
      '*',
      '@',
      '+'
    };
  /** Table des rgles */
  static String regles[][] =
  {
{"####+","*"},
{"####>","*"},
{"###+#","*"},
{"###^#","*"},
{"##+##","*"},
{"##<##","*"},
{"##<#^","B"},
{"##<#v","B"},
{"##^#>","B"},
{"##v#>","B"},
{"#+###","*"},
{"#<#^#","B"},
{"#>#^#","B"},
{"#v###","*"},
{"#v#<#","B"},
{"#v#>#","B"},
{"*###*",">"},
{"*###<","#"},
{"*###@","#"},
{"*###B","B"},
{"*###L","L"},
{"*###R","R"},
{"*###S","S"},
{"*###^","#"},
{"*###v","#"},
{"*##*#","^"},
{"*##*<","*"},
{"*##*@","<"},
{"*##*^","*"},
{"*##<#","#"},
{"*##<>","*"},
{"*##>#","#"},
{"*##>*","*"},
{"*##>>","*"},
{"*##@#","#"},
{"*##@*","v"},
{"*##@<","B"},
{"*##@>","v"},
{"*##@L","*"},
{"*##@R","*"},
{"*##@S","*"},
{"*##B#","B"},
{"*##B<","@"},
{"*##L#","L"},
{"*##L@","*"},
{"*##LL","*"},
{"*##LR","*"},
{"*##LS","*"},
{"*##R#","R"},
{"*##R@","*"},
{"*##RL","*"},
{"*##RR","*"},
{"*##RS","*"},
{"*##S#","S"},
{"*##S@","*"},
{"*##SL","*"},
{"*##SR","*"},
{"*##SS","*"},
{"*##^<","*"},
{"*##^@","<"},
{"*##^^","*"},
{"*##^v","*"},
{"*##v#","#"},
{"*##v*","*"},
{"*##v>","*"},
{"*##v@","B"},
{"*##vB","@"},
{"*#*##","<"},
{"*#*#<","*"},
{"*#*#@","<"},
{"*#*#L","@"},
{"*#*#R","@"},
{"*#*#S","@"},
{"*#*#^","*"},
{"*#*#v","*"},
{"*#*<#","*"},
{"*#*@#","v"},
{"*#*SS","S"},
{"*#*v#","*"},
{"*#<#<","*"},
{"*#<#@","<"},
{"*#<#B","<"},
{"*#<#^","*"},
{"*#<#v","*"},
{"*#<<#","*"},
{"*#<>#","*"},
{"*#<@#","v"},
{"*#<v#","*"},
{"*#>##","#"},
{"*#>#*","*"},
{"*#>#>","*"},
{"*#>#^","*"},
{"*#>#v","*"},
{"*#>*#","*"},
{"*#>@#","B"},
{"*#>B#","@"},
{"*#>^#","*"},
{"*#>v<","#"},
{"*#@##","#"},
{"*#@#*",">"},
{"*#@#>",">"},
{"*#@#L","*"},
{"*#@#R","*"},
{"*#@#S","*"},
{"*#@#^","*"},
{"*#@#v","*"},
{"*#@*#",">"},
{"*#@L#","*"},
{"*#@R#","*"},
{"*#@S#","*"},
{"*#@^#",">"},
{"*#@v#","B"},
{"*#B##","B"},
{"*#B#>",">"},
{"*#Bv#","@"},
{"*#L##","L"},
{"*#L#*","@"},
{"*#L#@","*"},
{"*#L#L","*"},
{"*#L#R","*"},
{"*#L#S","*"},
{"*#L@#","*"},
{"*#LL#","*"},
{"*#LR#","*"},
{"*#LS#","*"},
{"*#R##","R"},
{"*#R#*","@"},
{"*#R#@","*"},
{"*#R#L","*"},
{"*#R#R","*"},
{"*#R#S","*"},
{"*#R@#","*"},
{"*#RL#","*"},
{"*#RR#","*"},
{"*#RS#","*"},
{"*#S##","S"},
{"*#S#*","@"},
{"*#S#@","*"},
{"*#S#L","*"},
{"*#S#R","*"},
{"*#S#S","*"},
{"*#S@#","*"},
{"*#SL#","*"},
{"*#SR#","*"},
{"*#SS#","*"},
{"*#SS*","S"},
{"*#^##","#"},
{"*#^#*","*"},
{"*#^#<","*"},
{"*#^#>","*"},
{"*#^#@","*"},
{"*#^#^","*"},
{"*#^#v","*"},
{"*#^*#","*"},
{"*#^^#","*"},
{"*#v##","#"},
{"*#v#*","*"},
{"*#v#<","*"},
{"*#v#>","*"},
{"*#v#@","*"},
{"*#v#^","*"},
{"*#v#v","*"},
{"*#v^#","*"},
{"**###","v"},
{"**##<","*"},
{"**##@","<"},
{"**##v","*"},
{"**#<#","*"},
{"**#>#","*"},
{"**#@#","v"},
{"**#L#","@"},
{"**#R#","@"},
{"**#S#","@"},
{"**#SS","S"},
{"**#v#","*"},
{"**>##","*"},
{"**@##",">"},
{"**SS#","S"},
{"**v##","*"},
{"*<###","#"},
{"*<##>","*"},
{"*<#*#","*"},
{"*<#<#","*"},
{"*<#>#","*"},
{"*<#@#","*"},
{"*<#^#","*"},
{"*<#v#","*"},
{"*<*##","*"},
{"*<<##","*"},
{"*>###","#"},
{"*>##*","*"},
{"*>##>","*"},
{"*>#*#","*"},
{"*>#<#","*"},
{"*>#>#","*"},
{"*>#@#","*"},
{"*>#^#","*"},
{"*>#v#","*"},
{"*><##","*"},
{"*@###","#"},
{"*@##*","^"},
{"*@##<","B"},
{"*@##>","^"},
{"*@##L","*"},
{"*@##R","*"},
{"*@##S","*"},
{"*@#*#","^"},
{"*@#<#","*"},
{"*@#>#","*"},
{"*@#L#","*"},
{"*@#R#","*"},
{"*@#S#","*"},
{"*@#^#","^"},
{"*@*##","^"},
{"*@<##","^"},
{"*@>##","B"},
{"*@L##","*"},
{"*@R##","*"},
{"*@S##","*"},
{"*B###","B"},
{"*B##<","@"},
{"*B#^#","^"},
{"*B>##","@"},
{"*L###","L"},
{"*L##@","*"},
{"*L##L","*"},
{"*L##R","*"},
{"*L##S","*"},
{"*L#*#","@"},
{"*L#@#","*"},
{"*L#L#","*"},
{"*L#R#","*"},
{"*L#S#","*"},
{"*L@##","*"},
{"*LL##","*"},
{"*LR##","*"},
{"*LS##","*"},
{"*R###","R"},
{"*R##@","*"},
{"*R##L","*"},
{"*R##R","*"},
{"*R##S","*"},
{"*R#*#","@"},
{"*R#@#","*"},
{"*R#L#","*"},
{"*R#R#","*"},
{"*R#S#","*"},
{"*R@##","*"},
{"*RL##","*"},
{"*RR##","*"},
{"*RS##","*"},
{"*S###","S"},
{"*S##@","*"},
{"*S##L","*"},
{"*S##R","*"},
{"*S##S","*"},
{"*S#*#","@"},
{"*S#*S","S"},
{"*S#@#","*"},
{"*S#L#","*"},
{"*S#R#","*"},
{"*S#S#","*"},
{"*S*#S","S"},
{"*S@##","*"},
{"*SL##","*"},
{"*SR##","*"},
{"*SS##","*"},
{"*SS#*","S"},
{"*SS*#","S"},
{"*^###","#"},
{"*^##*","*"},
{"*^##>","*"},
{"*^##@","B"},
{"*^##B","@"},
{"*^#*#","*"},
{"*^#<#","*"},
{"*^#>#","*"},
{"*^#^#","*"},
{"*^#v<","#"},
{"*^*##","*"},
{"*^<##","*"},
{"*^>#<","#"},
{"*^>v#","#"},
{"*^@##","B"},
{"*^B##","@"},
{"*v##<","*"},
{"*v##@","<"},
{"*v##^","*"},
{"*v##v","*"},
{"*v#<#","*"},
{"*v#>#","*"},
{"*v#@#","v"},
{"*v#B#","v"},
{"*v#v#","*"},
{"*v>##","*"},
{"*v@##",">"},
{"*v^##","*"},
{"*vv##","*"},
{"+###L","L"},
{"+###R","R"},
{"+###S","S"},
{"+##L#","L"},
{"+##R#","R"},
{"+##S#","S"},
{"+#L##","L"},
{"+#R##","R"},
{"+#S##","S"},
{"+L###","L"},
{"+LLLL","L"},
{"+LLLR","R"},
{"+LLLS","S"},
{"+LLRL","R"},
{"+LLSL","S"},
{"+LRLL","R"},
{"+LRRR","L"},
{"+LSLL","S"},
{"+LSSS","L"},
{"+R###","R"},
{"+RLLL","R"},
{"+RLRR","L"},
{"+RRLR","L"},
{"+RRRL","L"},
{"+RRRR","R"},
{"+RRRS","S"},
{"+RRSR","S"},
{"+RSRR","S"},
{"+RSSS","R"},
{"+S###","S"},
{"+SLLL","S"},
{"+SLSS","L"},
{"+SRRR","S"},
{"+SRSS","R"},
{"+SSLS","L"},
{"+SSRS","R"},
{"+SSSL","L"},
{"+SSSR","R"},
{"+SSSS","S"},
{"<###B","*"},
{"<###L","*"},
{"<###R","*"},
{"<###S","*"},
{"<##*#","L"},
{"<##*B","L"},
{"<##*L","L"},
{"<##*R","L"},
{"<##*S","L"},
{"<##@*","S"},
{"<##@L","^"},
{"<##@S","L"},
{"<##B#","B"},
{"<##BB","B"},
{"<##BL","B"},
{"<##BR","B"},
{"<##BS","B"},
{"<##L#","L"},
{"<##L*","L"},
{"<##L@","L"},
{"<##LB","L"},
{"<##LL","L"},
{"<##LR","L"},
{"<##LS","L"},
{"<##R#","R"},
{"<##R*","R"},
{"<##R@","R"},
{"<##RB","R"},
{"<##RL","R"},
{"<##RR","R"},
{"<##RS","R"},
{"<##S#","S"},
{"<##S*","S"},
{"<##S@","S"},
{"<##SB","S"},
{"<##SL","S"},
{"<##SR","S"},
{"<##SS","S"},
{"<#*##","S"},
{"<#*#B","S"},
{"<#*#L","S"},
{"<#*#R","S"},
{"<#*#S","S"},
{"<#<##","B"},
{"<#<#S","B"},
{"<#>#S","#"},
{"<#>v>","v"},
{"<#@#*","S"},
{"<#@#S","@"},
{"<#@v#","*"},
{"<#B##","B"},
{"<#B#B","B"},
{"<#B#L","B"},
{"<#B#R","B"},
{"<#B#S","B"},
{"<#L##","L"},
{"<#L#*","L"},
{"<#L#@","L"},
{"<#L#B","L"},
{"<#L#L","L"},
{"<#L#R","L"},
{"<#L#S","L"},
{"<#L*S","L"},
{"<#L@L","L"},
{"<#L@R","L"},
{"<#L@S","L"},
{"<#LSL","L"},
{"<#LSR","L"},
{"<#LSS","L"},
{"<#R##","R"},
{"<#R#*","R"},
{"<#R#@","R"},
{"<#R#B","R"},
{"<#R#L","R"},
{"<#R#R","R"},
{"<#R#S","R"},
{"<#R*S","R"},
{"<#R@L","R"},
{"<#R@R","R"},
{"<#R@S","R"},
{"<#RSL","R"},
{"<#RSR","R"},
{"<#RSS","R"},
{"<#S##","S"},
{"<#S#*","S"},
{"<#S#>","S"},
{"<#S#@","S"},
{"<#S#B","S"},
{"<#S#L","S"},
{"<#S#R","S"},
{"<#S#S","S"},
{"<#S*S","S"},
{"<#S@L","S"},
{"<#S@R","S"},
{"<#S@S","S"},
{"<#SSL","S"},
{"<#SSR","S"},
{"<#SSS","S"},
{"<#^##","S"},
{"<#^#L","S"},
{"<#^#S","S"},
{"<#v##","S"},
{"<#v#R","S"},
{"<#v#S","S"},
{"<*###","R"},
{"<*##B","R"},
{"<*##L","R"},
{"<*##R","R"},
{"<*##S","R"},
{"<*L#S","L"},
{"<*R#S","R"},
{"<*S#S","S"},
{"<@##*","S"},
{"<@##R","v"},
{"<@##S","R"},
{"<@L#L","L"},
{"<@L#R","L"},
{"<@L#S","L"},
{"<@R#L","R"},
{"<@R#R","R"},
{"<@R#S","R"},
{"<@S#L","S"},
{"<@S#R","S"},
{"<@S#S","S"},
{"<B###","B"},
{"<B##B","B"},
{"<B##L","B"},
{"<B##R","B"},
{"<B##S","B"},
{"<L###","L"},
{"<L##*","L"},
{"<L##@","L"},
{"<L##B","L"},
{"<L##L","L"},
{"<L##R","L"},
{"<L##S","L"},
{"<R###","R"},
{"<R##*","R"},
{"<R##@","R"},
{"<R##B","R"},
{"<R##L","R"},
{"<R##R","R"},
{"<R##S","R"},
{"<S###","S"},
{"<S##*","S"},
{"<S##@","S"},
{"<S##B","S"},
{"<S##L","S"},
{"<S##R","S"},
{"<S##S","S"},
{"<SL#L","L"},
{"<SL#R","L"},
{"<SL#S","L"},
{"<SR#L","R"},
{"<SR#R","R"},
{"<SR#S","R"},
{"<SS#L","S"},
{"<SS#R","S"},
{"<SS#S","S"},
{"<^#v<","@"},
{"<^>#>","^"},
{"<^@##","*"},
{">###*","S"},
{">###>","B"},
{">###B","B"},
{">###L","L"},
{">###R","R"},
{">###S","S"},
{">###^","S"},
{">###v","S"},
{">##*#","R"},
{">##B#","B"},
{">##L#","L"},
{">##R#","R"},
{">##S#","S"},
{">##v@","*"},
{">#*#@","S"},
{">#*#L","L"},
{">#*#R","R"},
{">#*#S","S"},
{">#*@#","S"},
{">#*L#","L"},
{">#*R#","R"},
{">#*S#","S"},
{">#<#S","S"},
{">#<v<","v"},
{">#@#L","L"},
{">#@#R","R"},
{">#@#S","S"},
{">#@L#","L"},
{">#@R#","R"},
{">#@S#","S"},
{">#B##","*"},
{">#B#*","S"},
{">#B#B","B"},
{">#B#L","L"},
{">#B#R","R"},
{">#B#S","S"},
{">#B*#","R"},
{">#BB#","B"},
{">#BL#","L"},
{">#BR#","R"},
{">#BS#","S"},
{">#L##","*"},
{">#L#*","S"},
{">#L#B","B"},
{">#L#L","L"},
{">#L#R","R"},
{">#L#S","S"},
{">#L#v","S"},
{">#L*#","R"},
{">#L@L","L"},
{">#L@R","R"},
{">#L@S","S"},
{">#LB#","B"},
{">#LL#","L"},
{">#LR#","R"},
{">#LS#","S"},
{">#LSL","L"},
{">#LSR","R"},
{">#LSS","S"},
{">#R##","*"},
{">#R#*","S"},
{">#R#B","B"},
{">#R#L","L"},
{">#R#R","R"},
{">#R#S","S"},
{">#R#^","S"},
{">#R*#","R"},
{">#R@#","^"},
{">#R@L","L"},
{">#R@R","R"},
{">#R@S","S"},
{">#RB#","B"},
{">#RL#","L"},
{">#RR#","R"},
{">#RS#","S"},
{">#RSL","L"},
{">#RSR","R"},
{">#RSS","S"},
{">#S##","*"},
{">#S#*","S"},
{">#S#<","#"},
{">#S#>","B"},
{">#S#@","@"},
{">#S#B","B"},
{">#S#L","L"},
{">#S#R","R"},
{">#S#S","S"},
{">#S#^","S"},
{">#S#v","S"},
{">#S*#","R"},
{">#S*L","L"},
{">#S*R","R"},
{">#S*S","S"},
{">#S@#","R"},
{">#S@L","L"},
{">#S@R","R"},
{">#S@S","S"},
{">#SB#","B"},
{">#SL#","L"},
{">#SR#","R"},
{">#SS#","S"},
{">#SSL","L"},
{">#SSR","R"},
{">#SSS","S"},
{">*###","L"},
{">*B##","L"},
{">*L##","L"},
{">*R##","L"},
{">*S##","L"},
{">*S#L","L"},
{">*S#R","R"},
{">*S#S","S"},
{">@*##","S"},
{">@L##","v"},
{">@L#L","L"},
{">@L#R","R"},
{">@L#S","S"},
{">@R#L","L"},
{">@R#R","R"},
{">@R#S","S"},
{">@S##","L"},
{">@S#L","L"},
{">@S#R","R"},
{">@S#S","S"},
{">B###","B"},
{">BB##","B"},
{">BL##","B"},
{">BR##","B"},
{">BS##","B"},
{">L###","L"},
{">L*##","L"},
{">L@##","L"},
{">LB##","L"},
{">LL##","L"},
{">LR##","L"},
{">LS##","L"},
{">R###","R"},
{">R*##","R"},
{">R@##","R"},
{">RB##","R"},
{">RL##","R"},
{">RR##","R"},
{">RS##","R"},
{">S###","S"},
{">S*##","S"},
{">S@##","S"},
{">SB##","S"},
{">SL##","S"},
{">SL#L","L"},
{">SL#R","R"},
{">SL#S","S"},
{">SR##","S"},
{">SR#L","L"},
{">SR#R","R"},
{">SR#S","S"},
{">SS##","S"},
{">SS#L","L"},
{">SS#R","R"},
{">SS#S","S"},
{">^##@","*"},
{">^<#<","^"},
{">^>v#","@"},
{"@###L","L"},
{"@###R","R"},
{"@###S","S"},
{"@##*L","*"},
{"@##*R","*"},
{"@##*S","*"},
{"@##@S","*"},
{"@##L#","L"},
{"@##L*","*"},
{"@##R#","R"},
{"@##R*","*"},
{"@##S#","S"},
{"@##S*","*"},
{"@##S@","*"},
{"@##^<","<"},
{"@##v>","v"},
{"@#*#L","*"},
{"@#*#R","*"},
{"@#*#S","*"},
{"@#*#^","*"},
{"@#*#v","*"},
{"@#*L#","*"},
{"@#*R#","*"},
{"@#*S#","*"},
{"@#*SS",">"},
{"@#<#<","<"},
{"@#<#@","@"},
{"@#<#^","@"},
{"@#<#v","@"},
{"@#<v#","v"},
{"@#>#>",">"},
{"@#>#S","S"},
{"@#>#^","S"},
{"@#>#v","S"},
{"@#>^#",">"},
{"@#@#>","@"},
{"@#@S#","*"},
{"@#L##","L"},
{"@#L#*","*"},
{"@#L#S","@"},
{"@#L*#","*"},
{"@#R##","R"},
{"@#R#*","*"},
{"@#R#S","@"},
{"@#R*#","*"},
{"@#S##","S"},
{"@#S#*","*"},
{"@#S#<","S"},
{"@#S#L","@"},
{"@#S#R","@"},
{"@#S#S","*"},
{"@#S*#","*"},
{"@#S@#","*"},
{"@#SBS","*"},
{"@#SS*","<"},
{"@#^#*","*"},
{"@#^#<","S"},
{"@#^#>","@"},
{"@#^#^","S"},
{"@#^#v","S"},
{"@#v#*","*"},
{"@#v#<","S"},
{"@#v#>","@"},
{"@#v#^","S"},
{"@#v#v","S"},
{"@*##L","*"},
{"@*##R","*"},
{"@*##S","*"},
{"@*#<#","*"},
{"@*#>#","*"},
{"@*#L#","*"},
{"@*#R#","*"},
{"@*#S#","*"},
{"@*#SS","^"},
{"@*L##","*"},
{"@*R##","*"},
{"@*S##","*"},
{"@*SS#","^"},
{"@*SSS","v"},
{"@<#*#","*"},
{"@<#<#","S"},
{"@<#>#","S"},
{"@<#^#","@"},
{"@<#v#","S"},
{"@>#*#","*"},
{"@>#<#","S"},
{"@>#>#","S"},
{"@>#^#","@"},
{"@>#v#","S"},
{"@@##S","*"},
{"@@#^#","@"},
{"@@S##","*"},
{"@BS#S","*"},
{"@L###","L"},
{"@L##*","*"},
{"@L#*#","*"},
{"@L#S#","@"},
{"@L*##","*"},
{"@LLLL","L"},
{"@LLLR","R"},
{"@LLLS","S"},
{"@LLRL","R"},
{"@LLSL","S"},
{"@LRLL","R"},
{"@LRRR","L"},
{"@LSLL","S"},
{"@LSSS","L"},
{"@R###","R"},
{"@R##*","*"},
{"@R#*#","*"},
{"@R#S#","@"},
{"@R*##","*"},
{"@RLLL","R"},
{"@RLRR","L"},
{"@RRLR","L"},
{"@RRRL","L"},
{"@RRRR","R"},
{"@RRRS","S"},
{"@RRSR","S"},
{"@RSRR","S"},
{"@RSSS","R"},
{"@S###","S"},
{"@S##*","*"},
{"@S##@","*"},
{"@S#*#","*"},
{"@S#*S","v"},
{"@S#L#","@"},
{"@S#R#","@"},
{"@S#S#","*"},
{"@S#SB","*"},
{"@S#v#","S"},
{"@S*##","*"},
{"@S*#S",">"},
{"@S*SS","<"},
{"@S@##","*"},
{"@SBS#","*"},
{"@SLLL","S"},
{"@SLSS","L"},
{"@SRRR","S"},
{"@SRSS","R"},
{"@SS#*","<"},
{"@SS*#","v"},
{"@SS*S","^"},
{"@SSLS","L"},
{"@SSRS","R"},
{"@SSS*",">"},
{"@SSSL","L"},
{"@SSSR","R"},
{"@SSSS","S"},
{"@^##>","^"},
{"@^#<#","S"},
{"@^#>#","S"},
{"@^#S#","S"},
{"@^#^#","^"},
{"@^<##","^"},
{"@v##<","<"},
{"@v#<#","@"},
{"@v#>#","@"},
{"@v#@#","@"},
{"@v#v#","v"},
{"@v>##",">"},
{"B###*","<"},
{"B###<","<"},
{"B###>","+"},
{"B###^","<"},
{"B###v","<"},
{"B##*#","v"},
{"B##*+","v"},
{"B##*>","v"},
{"B##*@","v"},
{"B##*S","@"},
{"B##+*","<"},
{"B##+<","<"},
{"B##+^","<"},
{"B##+v","<"},
{"B##<#","v"},
{"B##<+","v"},
{"B##<>","v"},
{"B##<@","v"},
{"B##>#","v"},
{"B##>+","v"},
{"B##>>","v"},
{"B##>@","v"},
{"B##@*","<"},
{"B##@<","<"},
{"B##@^","<"},
{"B##@v","<"},
{"B##S*","@"},
{"B##^#","+"},
{"B##^*","<"},
{"B##^<","<"},
{"B##^^","<"},
{"B##^v","<"},
{"B##v#","v"},
{"B##v+","v"},
{"B##v>","v"},
{"B##v@","v"},
{"B#*##",">"},
{"B#*#+",">"},
{"B#*#>",">"},
{"B#*#@",">"},
{"B#*#S","@"},
{"B#*+#",">"},
{"B#*@#",">"},
{"B#*S#","@"},
{"B#*^#",">"},
{"B#+#*","<"},
{"B#+#<","<"},
{"B#+#^","<"},
{"B#+#v","<"},
{"B#+*#","v"},
{"B#+<#","v"},
{"B#+>#","v"},
{"B#+v#","v"},
{"B#<##","+"},
{"B#<#*","<"},
{"B#<#<","<"},
{"B#<#^","<"},
{"B#<#v","<"},
{"B#<*#","v"},
{"B#<<#","v"},
{"B#<>#","v"},
{"B#<v#","v"},
{"B#>##",">"},
{"B#>#+",">"},
{"B#>#>",">"},
{"B#>#@",">"},
{"B#>+#",">"},
{"B#>@#",">"},
{"B#>^#",">"},
{"B#@#*","<"},
{"B#@#<","<"},
{"B#@#^","<"},
{"B#@#v","<"},
{"B#@*#","v"},
{"B#@<#","v"},
{"B#@>#","v"},
{"B#@v#","v"},
{"B#S#*","@"},
{"B#S*#","@"},
{"B#^##",">"},
{"B#^#+",">"},
{"B#^#>",">"},
{"B#^#@",">"},
{"B#^+#",">"},
{"B#^@#",">"},
{"B#^^#",">"},
{"B#v##",">"},
{"B#v#+",">"},
{"B#v#>",">"},
{"B#v#@",">"},
{"B#v+#",">"},
{"B#v@#",">"},
{"B#v^#",">"},
{"B*###","^"},
{"B*##+","^"},
{"B*##>","^"},
{"B*##@","^"},
{"B*##S","@"},
{"B*#+#","^"},
{"B*#@#","^"},
{"B*#S#","@"},
{"B*#^#","^"},
{"B*+##","^"},
{"B*<##","^"},
{"B*@##","^"},
{"B*S##","@"},
{"B+##*","<"},
{"B+##<","<"},
{"B+##^","<"},
{"B+##v","<"},
{"B+#*#","v"},
{"B+#<#","v"},
{"B+#>#","v"},
{"B+#v#","v"},
{"B+*##",">"},
{"B+>##",">"},
{"B+^##",">"},
{"B+v##",">"},
{"B<###","^"},
{"B<##+","^"},
{"B<##>","^"},
{"B<##@","^"},
{"B<#+#","^"},
{"B<#@#","^"},
{"B<#^#","^"},
{"B<+##","^"},
{"B<<##","^"},
{"B<@##","^"},
{"B>###","^"},
{"B>##+","^"},
{"B>##>","^"},
{"B>##@","^"},
{"B>#+#","^"},
{"B>#@#","^"},
{"B>#^#","^"},
{"B>+##","^"},
{"B><##","^"},
{"B>@##","^"},
{"B@##*","<"},
{"B@##<","<"},
{"B@##^","<"},
{"B@##v","<"},
{"B@#*#","v"},
{"B@#<#","v"},
{"B@#>#","v"},
{"B@#v#","v"},
{"B@*##",">"},
{"B@>##",">"},
{"B@^##",">"},
{"B@v##",">"},
{"BS##*","@"},
{"BS#*#","@"},
{"BS*##","@"},
{"B^###","^"},
{"B^##+","^"},
{"B^##>","^"},
{"B^##@","^"},
{"B^#+#","^"},
{"B^#@#","^"},
{"B^#^#","^"},
{"B^+##","^"},
{"B^<##","^"},
{"B^@##","^"},
{"Bv###","+"},
{"Bv##*","<"},
{"Bv##<","<"},
{"Bv##^","<"},
{"Bv##v","<"},
{"Bv#*#","v"},
{"Bv#<#","v"},
{"Bv#>#","v"},
{"Bv#v#","v"},
{"Bv*##",">"},
{"Bv>##",">"},
{"Bv^##",">"},
{"Bvv##",">"},
{"L###*","<"},
{"L###+","^"},
{"L###<","<"},
{"L###>","^"},
{"L###@","<"},
{"L###^","<"},
{"L###v","<"},
{"L##*#","v"},
{"L##*+","v"},
{"L##*<","@"},
{"L##*>","v"},
{"L##*@","v"},
{"L##*^","@"},
{"L##*v","@"},
{"L##+#","<"},
{"L##+*","<"},
{"L##+<","<"},
{"L##+>","v"},
{"L##+^","<"},
{"L##+v","<"},
{"L##<#","v"},
{"L##<*","@"},
{"L##<+","v"},
{"L##<>","v"},
{"L##<@","v"},
{"L##>#","v"},
{"L##>*","@"},
{"L##>+","v"},
{"L##>>","v"},
{"L##>@","v"},
{"L##@#","v"},
{"L##@*","<"},
{"L##@<","<"},
{"L##@>","v"},
{"L##@^","<"},
{"L##@v","<"},
{"L##^#","<"},
{"L##^*","<"},
{"L##^+","<"},
{"L##^<","<"},
{"L##^@","<"},
{"L##^^","<"},
{"L##^v","<"},
{"L##v#","v"},
{"L##v*","@"},
{"L##v+","v"},
{"L##v>","v"},
{"L##v@","v"},
{"L#*##",">"},
{"L#*#+",">"},
{"L#*#<","@"},
{"L#*#>",">"},
{"L#*#@",">"},
{"L#*#^","@"},
{"L#*#v","@"},
{"L#*+#",">"},
{"L#*<#","@"},
{"L#*>#","@"},
{"L#*@#",">"},
{"L#*^#",">"},
{"L#*v#","@"},
{"L#+##","v"},
{"L#+#*","<"},
{"L#+#<","<"},
{"L#+#>",">"},
{"L#+#^","<"},
{"L#+#v","<"},
{"L#+*#","v"},
{"L#+<#","v"},
{"L#+>#","v"},
{"L#+^#",">"},
{"L#+v#","v"},
{"L#<##","v"},
{"L#<#*","<"},
{"L#<#+","<"},
{"L#<#<","<"},
{"L#<#@","<"},
{"L#<#^","<"},
{"L#<#v","<"},
{"L#<*#","v"},
{"L#<*<","<"},
{"L#<+#","v"},
{"L#<<#","v"},
{"L#<>#","v"},
{"L#<@#","v"},
{"L#<S<","<"},
{"L#<v#","v"},
{"L#>##",">"},
{"L#>#*","@"},
{"L#>#+",">"},
{"L#>#>",">"},
{"L#>#@",">"},
{"L#>*#","@"},
{"L#>*>",">"},
{"L#>+#",">"},
{"L#>@#",">"},
{"L#>S>",">"},
{"L#>^#",">"},
{"L#@##",">"},
{"L#@#*","<"},
{"L#@#<","<"},
{"L#@#>",">"},
{"L#@#^","<"},
{"L#@#v","<"},
{"L#@*#","v"},
{"L#@<#","v"},
{"L#@>#","v"},
{"L#@^#",">"},
{"L#@v#","v"},
{"L#^##",">"},
{"L#^#*","@"},
{"L#^#+",">"},
{"L#^#>",">"},
{"L#^#@",">"},
{"L#^*#","@"},
{"L#^+#",">"},
{"L#^@#",">"},
{"L#^^#",">"},
{"L#v##",">"},
{"L#v#*","@"},
{"L#v#+",">"},
{"L#v#>",">"},
{"L#v#@",">"},
{"L#v*#","@"},
{"L#v+#",">"},
{"L#v@#",">"},
{"L#v^#",">"},
{"L*###","^"},
{"L*##+","^"},
{"L*##<","@"},
{"L*##>","^"},
{"L*##@","^"},
{"L*##^","@"},
{"L*##v","@"},
{"L*#+#","^"},
{"L*#<#","@"},
{"L*#>#","@"},
{"L*#@#","^"},
{"L*#^#","^"},
{"L*#v#","@"},
{"L***>","+"},
{"L**^*","+"},
{"L*+##","^"},
{"L*<##","^"},
{"L*<#<","<"},
{"L*<**","+"},
{"L*>##","@"},
{"L*>#>",">"},
{"L*@##","^"},
{"L*^##","@"},
{"L*v##","@"},
{"L+###",">"},
{"L+##*","<"},
{"L+##<","<"},
{"L+##>","^"},
{"L+##^","<"},
{"L+##v","<"},
{"L+#*#","v"},
{"L+#<#","v"},
{"L+#>#","v"},
{"L+#^#","^"},
{"L+#v#","v"},
{"L+*##",">"},
{"L+<##","^"},
{"L+>##",">"},
{"L+^##",">"},
{"L+v##",">"},
{"L<###","^"},
{"L<##*","@"},
{"L<##+","^"},
{"L<##>","^"},
{"L<##@","^"},
{"L<#*#","@"},
{"L<#+#","^"},
{"L<#@#","^"},
{"L<#^#","^"},
{"L<*##","@"},
{"L<+##","^"},
{"L<<##","^"},
{"L<@##","^"},
{"L>###","^"},
{"L>##*","@"},
{"L>##+","^"},
{"L>##>","^"},
{"L>##@","^"},
{"L>#*#","@"},
{"L>#+#","^"},
{"L>#@#","^"},
{"L>#^#","^"},
{"L>*##","@"},
{"L>+##","^"},
{"L><##","^"},
{"L>@##","^"},
{"L@###","^"},
{"L@##*","<"},
{"L@##<","<"},
{"L@##>","^"},
{"L@##^","<"},
{"L@##v","<"},
{"L@#*#","v"},
{"L@#<#","v"},
{"L@#>#","v"},
{"L@#^#","^"},
{"L@#v#","v"},
{"L@*##",">"},
{"L@<##","^"},
{"L@>##",">"},
{"L@^##",">"},
{"L@v##",">"},
{"LS<#<","<"},
{"LS>#>",">"},
{"L^###","^"},
{"L^##*","@"},
{"L^##+","^"},
{"L^##>","^"},
{"L^##@","^"},
{"L^#*#","@"},
{"L^#+#","^"},
{"L^#@#","^"},
{"L^#^#","^"},
{"L^#^*","^"},
{"L^#^S","^"},
{"L^*##","@"},
{"L^*^#","^"},
{"L^+##","^"},
{"L^<##","^"},
{"L^<v<","@"},
{"L^>^<","@"},
{"L^>v>","@"},
{"L^@##","^"},
{"L^S^#","^"},
{"Lv###",">"},
{"Lv##*","<"},
{"Lv##+","<"},
{"Lv##<","<"},
{"Lv##@","<"},
{"Lv##^","<"},
{"Lv##v","<"},
{"Lv#*#","v"},
{"Lv#+#","v"},
{"Lv#<#","v"},
{"Lv#>#","v"},
{"Lv#@#","v"},
{"Lv#v#","v"},
{"Lv#v*","v"},
{"Lv#vS","v"},
{"Lv*##",">"},
{"Lv***","+"},
{"Lv*v#","v"},
{"Lv+##",">"},
{"Lv>##",">"},
{"Lv>v<","@"},
{"Lv@##",">"},
{"LvSv#","v"},
{"Lv^##",">"},
{"Lvv##",">"},
{"R###*","<"},
{"R###+","v"},
{"R###<","<"},
{"R###>","v"},
{"R###@","<"},
{"R###^","<"},
{"R###v","<"},
{"R##*#","v"},
{"R##*+","v"},
{"R##*<","@"},
{"R##*>","v"},
{"R##*@","v"},
{"R##*^","@"},
{"R##*v","@"},
{"R##+#",">"},
{"R##+*","<"},
{"R##+<","<"},
{"R##+>","v"},
{"R##+^","<"},
{"R##+v","<"},
{"R##<#","v"},
{"R##<*","@"},
{"R##<+","v"},
{"R##<>","v"},
{"R##<@","v"},
{"R##>#","v"},
{"R##>*","@"},
{"R##>+","v"},
{"R##>>","v"},
{"R##>@","v"},
{"R##@#","v"},
{"R##@*","<"},
{"R##@<","<"},
{"R##@>","v"},
{"R##@^","<"},
{"R##@v","<"},
{"R##^#",">"},
{"R##^*","<"},
{"R##^+","<"},
{"R##^<","<"},
{"R##^@","<"},
{"R##^^","<"},
{"R##^v","<"},
{"R##v#","v"},
{"R##v*","@"},
{"R##v+","v"},
{"R##v>","v"},
{"R##v@","v"},
{"R#*##",">"},
{"R#*#+",">"},
{"R#*#<","@"},
{"R#*#>",">"},
{"R#*#@",">"},
{"R#*#^","@"},
{"R#*#v","@"},
{"R#*+#",">"},
{"R#*<#","@"},
{"R#*>#","@"},
{"R#*@#",">"},
{"R#*^#",">"},
{"R#*v#","@"},
{"R#+##","^"},
{"R#+#*","<"},
{"R#+#<","<"},
{"R#+#>",">"},
{"R#+#^","<"},
{"R#+#v","<"},
{"R#+*#","v"},
{"R#+<#","v"},
{"R#+>#","v"},
{"R#+^#",">"},
{"R#+v#","v"},
{"R#<##","^"},
{"R#<#*","<"},
{"R#<#+","<"},
{"R#<#<","<"},
{"R#<#@","<"},
{"R#<#^","<"},
{"R#<#v","<"},
{"R#<*#","v"},
{"R#<*<","<"},
{"R#<+#","v"},
{"R#<<#","v"},
{"R#<>#","v"},
{"R#<@#","v"},
{"R#<S<","<"},
{"R#<v#","v"},
{"R#>##",">"},
{"R#>#*","@"},
{"R#>#+",">"},
{"R#>#>",">"},
{"R#>#@",">"},
{"R#>*#","@"},
{"R#>*>",">"},
{"R#>+#",">"},
{"R#>@#",">"},
{"R#>S>",">"},
{"R#>^#",">"},
{"R#@##",">"},
{"R#@#*","<"},
{"R#@#<","<"},
{"R#@#>",">"},
{"R#@#^","<"},
{"R#@#v","<"},
{"R#@*#","v"},
{"R#@<#","v"},
{"R#@>#","v"},
{"R#@^#",">"},
{"R#@v#","v"},
{"R#^##",">"},
{"R#^#*","@"},
{"R#^#+",">"},
{"R#^#>",">"},
{"R#^#@",">"},
{"R#^*#","@"},
{"R#^+#",">"},
{"R#^@#",">"},
{"R#^^#",">"},
{"R#v##",">"},
{"R#v#*","@"},
{"R#v#+",">"},
{"R#v#>",">"},
{"R#v#@",">"},
{"R#v*#","@"},
{"R#v+#",">"},
{"R#v@#",">"},
{"R#v^#",">"},
{"R*###","^"},
{"R*##+","^"},
{"R*##<","@"},
{"R*##>","^"},
{"R*##@","^"},
{"R*##^","@"},
{"R*##v","@"},
{"R*#+#","^"},
{"R*#<#","@"},
{"R*#>#","@"},
{"R*#@#","^"},
{"R*#^#","^"},
{"R*#v#","@"},
{"R***>","+"},
{"R**^*","+"},
{"R*+##","^"},
{"R*<##","^"},
{"R*<#<","<"},
{"R*<**","+"},
{"R*>##","@"},
{"R*>#>",">"},
{"R*@##","^"},
{"R*^##","@"},
{"R*v##","@"},
{"R+###","<"},
{"R+##*","<"},
{"R+##<","<"},
{"R+##>","^"},
{"R+##^","<"},
{"R+##v","<"},
{"R+#*#","v"},
{"R+#<#","v"},
{"R+#>#","v"},
{"R+#^#","^"},
{"R+#v#","v"},
{"R+*##",">"},
{"R+<##","^"},
{"R+>##",">"},
{"R+^##",">"},
{"R+v##",">"},
{"R<###","^"},
{"R<##*","@"},
{"R<##+","^"},
{"R<##>","^"},
{"R<##@","^"},
{"R<#*#","@"},
{"R<#+#","^"},
{"R<#@#","^"},
{"R<#^#","^"},
{"R<*##","@"},
{"R<+##","^"},
{"R<<##","^"},
{"R<@##","^"},
{"R>###","^"},
{"R>##*","@"},
{"R>##+","^"},
{"R>##>","^"},
{"R>##@","^"},
{"R>#*#","@"},
{"R>#+#","^"},
{"R>#@#","^"},
{"R>#^#","^"},
{"R>*##","@"},
{"R>+##","^"},
{"R><##","^"},
{"R>@##","^"},
{"R@###","^"},
{"R@##*","<"},
{"R@##<","<"},
{"R@##>","^"},
{"R@##^","<"},
{"R@##v","<"},
{"R@#*#","v"},
{"R@#<#","v"},
{"R@#>#","v"},
{"R@#^#","^"},
{"R@#v#","v"},
{"R@*##",">"},
{"R@<##","^"},
{"R@>##",">"},
{"R@^##",">"},
{"R@v##",">"},
{"RS<#<","<"},
{"RS>#>",">"},
{"R^###","^"},
{"R^##*","@"},
{"R^##+","^"},
{"R^##>","^"},
{"R^##@","^"},
{"R^#*#","@"},
{"R^#+#","^"},
{"R^#@#","^"},
{"R^#^#","^"},
{"R^#^*","^"},
{"R^#^S","^"},
{"R^*##","@"},
{"R^*^#","^"},
{"R^+##","^"},
{"R^<##","^"},
{"R^<v<","@"},
{"R^>^<","@"},
{"R^>v>","@"},
{"R^@##","^"},
{"R^S^#","^"},
{"Rv###","<"},
{"Rv##*","<"},
{"Rv##+","<"},
{"Rv##<","<"},
{"Rv##@","<"},
{"Rv##^","<"},
{"Rv##v","<"},
{"Rv#*#","v"},
{"Rv#+#","v"},
{"Rv#<#","v"},
{"Rv#>#","v"},
{"Rv#@#","v"},
{"Rv#v#","v"},
{"Rv#v*","v"},
{"Rv#vS","v"},
{"Rv*##",">"},
{"Rv***","+"},
{"Rv*v#","v"},
{"Rv+##",">"},
{"Rv>##",">"},
{"Rv>v<","@"},
{"Rv@##",">"},
{"RvSv#","v"},
{"Rv^##",">"},
{"Rvv##",">"},
{"S###*","<"},
{"S###+",">"},
{"S###<","<"},
{"S###>",">"},
{"S###@","<"},
{"S###^","<"},
{"S###v","<"},
{"S##*#","v"},
{"S##*+","v"},
{"S##*<","@"},
{"S##*>","v"},
{"S##*@","v"},
{"S##*S","v"},
{"S##*^","@"},
{"S##*v","@"},
{"S##+#","^"},
{"S##+*","<"},
{"S##+<","<"},
{"S##+>","v"},
{"S##+^","<"},
{"S##+v","<"},
{"S##<#","v"},
{"S##<*","@"},
{"S##<+","v"},
{"S##<>","v"},
{"S##<@","v"},
{"S##<S","v"},
{"S##>#","v"},
{"S##>*","@"},
{"S##>+","v"},
{"S##>>","v"},
{"S##>@","v"},
{"S##>S","v"},
{"S##@#","v"},
{"S##@*","<"},
{"S##@<","<"},
{"S##@>","v"},
{"S##@^","<"},
{"S##@v","<"},
{"S##B>","v"},
{"S##S*","<"},
{"S##S<","<"},
{"S##S^","<"},
{"S##Sv","<"},
{"S##^#","^"},
{"S##^*","<"},
{"S##^+","<"},
{"S##^<","<"},
{"S##^@","<"},
{"S##^B","<"},
{"S##^^","<"},
{"S##^v","<"},
{"S##v#","v"},
{"S##v*","@"},
{"S##v+","v"},
{"S##v>","v"},
{"S##v@","v"},
{"S##vS","v"},
{"S#*##",">"},
{"S#*#+",">"},
{"S#*#<","@"},
{"S#*#>",">"},
{"S#*#@",">"},
{"S#*#S",">"},
{"S#*#^","@"},
{"S#*#v","@"},
{"S#*+#",">"},
{"S#*<#","@"},
{"S#*>#","@"},
{"S#*@#",">"},
{"S#*S#",">"},
{"S#*^#",">"},
{"S#*v#","@"},
{"S#+##","<"},
{"S#+#*","<"},
{"S#+#<","<"},
{"S#+#>",">"},
{"S#+#^","<"},
{"S#+#v","<"},
{"S#+*#","v"},
{"S#+<#","v"},
{"S#+>#","v"},
{"S#+^#",">"},
{"S#+v#","v"},
{"S#<##","<"},
{"S#<#*","<"},
{"S#<#+","<"},
{"S#<#<","<"},
{"S#<#@","<"},
{"S#<#B","<"},
{"S#<#^","<"},
{"S#<#v","<"},
{"S#<*#","v"},
{"S#<*<","<"},
{"S#<+#","v"},
{"S#<<#","v"},
{"S#<>#","v"},
{"S#<@#","v"},
{"S#<@<","<"},
{"S#<B#","v"},
{"S#<S<","<"},
{"S#<v#","v"},
{"S#>##",">"},
{"S#>#*","@"},
{"S#>#+",">"},
{"S#>#>",">"},
{"S#>#@",">"},
{"S#>#B",">"},
{"S#>#S",">"},
{"S#>#^","S"},
{"S#>#v","S"},
{"S#>*#","@"},
{"S#>*>",">"},
{"S#>+#",">"},
{"S#>@#",">"},
{"S#>@>",">"},
{"S#>S#",">"},
{"S#>S>",">"},
{"S#>S@","@"},
{"S#>^#",">"},
{"S#@##",">"},
{"S#@#*","<"},
{"S#@#<","<"},
{"S#@#>",">"},
{"S#@#^","<"},
{"S#@#v","<"},
{"S#@*#","v"},
{"S#@<#","v"},
{"S#@>#","v"},
{"S#@S<","@"},
{"S#@^#",">"},
{"S#@v#","v"},
{"S#B#<","<"},
{"S#B#>",">"},
{"S#B#^","<"},
{"S#B#v","<"},
{"S#B^#",">"},
{"S#L#S","S"},
{"S#R#S","S"},
{"S#S#*","<"},
{"S#S#<","<"},
{"S#S#L","S"},
{"S#S#R","S"},
{"S#S#S","S"},
{"S#S#^","<"},
{"S#S#v","<"},
{"S#S*#","v"},
{"S#S<#","v"},
{"S#S>#","v"},
{"S#Sv#","v"},
{"S#^##",">"},
{"S#^#*","@"},
{"S#^#+",">"},
{"S#^#<","S"},
{"S#^#>",">"},
{"S#^#@",">"},
{"S#^#B",">"},
{"S#^#S",">"},
{"S#^#^","S"},
{"S#^#v","S"},
{"S#^*#","@"},
{"S#^+#",">"},
{"S#^@#",">"},
{"S#^S#",">"},
{"S#^^#",">"},
{"S#v##",">"},
{"S#v#*","@"},
{"S#v#+",">"},
{"S#v#<","S"},
{"S#v#>",">"},
{"S#v#@",">"},
{"S#v#B",">"},
{"S#v#S",">"},
{"S#v#^","S"},
{"S#v#v","S"},
{"S#v*#","@"},
{"S#v+#",">"},
{"S#v@#",">"},
{"S#vS#",">"},
{"S#v^#",">"},
{"S*###","^"},
{"S*##+","^"},
{"S*##<","@"},
{"S*##>","^"},
{"S*##@","^"},
{"S*##S","^"},
{"S*##^","@"},
{"S*##v","@"},
{"S*#+#","^"},
{"S*#<#","@"},
{"S*#>#","@"},
{"S*#@#","^"},
{"S*#S#","^"},
{"S*#^#","^"},
{"S*#v#","@"},
{"S***>","+"},
{"S**^*","+"},
{"S*+##","^"},
{"S*<##","^"},
{"S*<#<","<"},
{"S*<**","+"},
{"S*>##","@"},
{"S*>#>",">"},
{"S*@##","^"},
{"S*S##","^"},
{"S*^##","@"},
{"S*v##","@"},
{"S+###","v"},
{"S+##*","<"},
{"S+##<","<"},
{"S+##>","^"},
{"S+##^","<"},
{"S+##v","<"},
{"S+#*#","v"},
{"S+#<#","v"},
{"S+#>#","v"},
{"S+#^#","^"},
{"S+#v#","v"},
{"S+*##",">"},
{"S+<##","^"},
{"S+>##",">"},
{"S+^##",">"},
{"S+v##",">"},
{"S<###","^"},
{"S<##*","@"},
{"S<##+","^"},
{"S<##>","^"},
{"S<##@","^"},
{"S<##S","^"},
{"S<#*#","@"},
{"S<#+#","^"},
{"S<#<#","S"},
{"S<#>#","S"},
{"S<#@#","^"},
{"S<#B#","^"},
{"S<#S#","^"},
{"S<#^#","^"},
{"S<#v#","S"},
{"S<*##","@"},
{"S<+##","^"},
{"S<<##","^"},
{"S<@##","^"},
{"S<S##","^"},
{"S>###","^"},
{"S>##*","@"},
{"S>##+","^"},
{"S>##>","^"},
{"S>##@","^"},
{"S>##S","^"},
{"S>#*#","@"},
{"S>#+#","^"},
{"S>#<#","S"},
{"S>#>#","S"},
{"S>#@#","^"},
{"S>#B#","^"},
{"S>#S#","^"},
{"S>#^#","^"},
{"S>#v#","S"},
{"S>*##","@"},
{"S>+##","^"},
{"S><##","^"},
{"S>@##","^"},
{"S>S##","^"},
{"S@###","^"},
{"S@##*","<"},
{"S@##<","<"},
{"S@##>","^"},
{"S@##^","<"},
{"S@##v","<"},
{"S@#*#","v"},
{"S@#<#","v"},
{"S@#>#","v"},
{"S@#^#","^"},
{"S@#v#","v"},
{"S@#vS","@"},
{"S@*##",">"},
{"S@<##","^"},
{"S@<#<","<"},
{"S@>##",">"},
{"S@>#>",">"},
{"S@Sv#","@"},
{"S@^##",">"},
{"S@v##",">"},
{"SB##>","^"},
{"SB#<#","v"},
{"SB#>#","v"},
{"SB#^#","^"},
{"SB#v#","v"},
{"SB<##","^"},
{"SL#S#","S"},
{"SR#S#","S"},
{"SS##*","<"},
{"SS##<","<"},
{"SS##^","<"},
{"SS##v","<"},
{"SS#*#","v"},
{"SS#<#","v"},
{"SS#>#","v"},
{"SS#L#","S"},
{"SS#R#","S"},
{"SS#S#","S"},
{"SS#v#","v"},
{"SS*##",">"},
{"SS<#<","<"},
{"SS>##",">"},
{"SS>#>",">"},
{"SS>#@","@"},
{"SS@#<","@"},
{"SS^##",">"},
{"SSv##",">"},
{"S^###","^"},
{"S^##*","@"},
{"S^##+","^"},
{"S^##>","^"},
{"S^##@","^"},
{"S^##S","^"},
{"S^#*#","@"},
{"S^#+#","^"},
{"S^#<#","S"},
{"S^#>#","S"},
{"S^#@#","^"},
{"S^#@S","@"},
{"S^#B#","^"},
{"S^#S#","^"},
{"S^#^#","^"},
{"S^#^*","^"},
{"S^#^@","^"},
{"S^#^S","^"},
{"S^*##","@"},
{"S^*^#","^"},
{"S^+##","^"},
{"S^<##","^"},
{"S^<v<","@"},
{"S^>^<","@"},
{"S^>v>","@"},
{"S^@##","^"},
{"S^@^#","^"},
{"S^S##","^"},
{"S^S@#","@"},
{"S^S^#","^"},
{"Sv###","v"},
{"Sv##*","<"},
{"Sv##+","<"},
{"Sv##<","<"},
{"Sv##@","<"},
{"Sv##B","<"},
{"Sv##^","<"},
{"Sv##v","<"},
{"Sv#*#","v"},
{"Sv#+#","v"},
{"Sv#<#","v"},
{"Sv#>#","v"},
{"Sv#@#","v"},
{"Sv#B#","v"},
{"Sv#v#","v"},
{"Sv#v*","v"},
{"Sv#v@","v"},
{"Sv#vS","v"},
{"Sv*##",">"},
{"Sv***","+"},
{"Sv*v#","v"},
{"Sv+##",">"},
{"Sv>##",">"},
{"Sv>v<","@"},
{"Sv@##",">"},
{"Sv@v#","v"},
{"SvB##",">"},
{"SvSv#","v"},
{"Sv^##",">"},
{"Svv##",">"},
{"^###*","L"},
{"^###B","B"},
{"^###L","L"},
{"^###R","R"},
{"^###S","S"},
{"^##*#","S"},
{"^##<#","S"},
{"^##>#","S"},
{"^##@<","*"},
{"^##B#","B"},
{"^##L#","L"},
{"^##R#","R"},
{"^##S#","S"},
{"^##^#","B"},
{"^#*##","R"},
{"^#>@#","*"},
{"^#B##","B"},
{"^#L##","L"},
{"^#R##","R"},
{"^#S##","S"},
{"^*##@","S"},
{"^*##L","L"},
{"^*##R","R"},
{"^*##S","S"},
{"^*#@#","S"},
{"^*#L#","L"},
{"^*#R#","R"},
{"^*#S#","S"},
{"^*@##","S"},
{"^*L##","L"},
{"^*R##","R"},
{"^*S##","S"},
{"^@##L","L"},
{"^@##R","R"},
{"^@##S","S"},
{"^@#L#","L"},
{"^@#R#","R"},
{"^@#S#","S"},
{"^@L##","L"},
{"^@R##","R"},
{"^@S##","S"},
{"^B###","*"},
{"^B##*","L"},
{"^B##B","B"},
{"^B##L","L"},
{"^B##R","R"},
{"^B##S","S"},
{"^B#*#","S"},
{"^B#B#","B"},
{"^B#L#","L"},
{"^B#R#","R"},
{"^B#S#","S"},
{"^B*##","R"},
{"^BB##","B"},
{"^BL##","L"},
{"^BR##","R"},
{"^BS##","S"},
{"^L###","*"},
{"^L##*","L"},
{"^L##@",">"},
{"^L##B","B"},
{"^L##L","L"},
{"^L##R","R"},
{"^L##S","S"},
{"^L#*#","S"},
{"^L#>#","S"},
{"^L#B#","B"},
{"^L#L#","L"},
{"^L#L@","L"},
{"^L#LS","L"},
{"^L#R#","R"},
{"^L#R@","R"},
{"^L#RS","R"},
{"^L#S#","S"},
{"^L#S@","S"},
{"^L#SS","S"},
{"^L*##","R"},
{"^L@L#","L"},
{"^L@R#","R"},
{"^L@S#","S"},
{"^LB##","B"},
{"^LL##","L"},
{"^LR##","R"},
{"^LS##","S"},
{"^LSL#","L"},
{"^LSR#","R"},
{"^LSS#","S"},
{"^R###","*"},
{"^R##*","L"},
{"^R##B","B"},
{"^R##L","L"},
{"^R##R","R"},
{"^R##S","S"},
{"^R#*#","S"},
{"^R#<#","S"},
{"^R#B#","B"},
{"^R#L#","L"},
{"^R#L@","L"},
{"^R#LS","L"},
{"^R#R#","R"},
{"^R#R@","R"},
{"^R#RS","R"},
{"^R#S#","S"},
{"^R#S@","S"},
{"^R#SS","S"},
{"^R*##","R"},
{"^R@##","<"},
{"^R@L#","L"},
{"^R@R#","R"},
{"^R@S#","S"},
{"^RB##","B"},
{"^RL##","L"},
{"^RR##","R"},
{"^RS##","S"},
{"^RSL#","L"},
{"^RSR#","R"},
{"^RSS#","S"},
{"^S###","*"},
{"^S##*","L"},
{"^S##@","L"},
{"^S##B","B"},
{"^S##L","L"},
{"^S##R","R"},
{"^S##S","S"},
{"^S#*#","S"},
{"^S#<#","S"},
{"^S#>#","S"},
{"^S#@#","@"},
{"^S#B#","B"},
{"^S#L#","L"},
{"^S#L*","L"},
{"^S#L@","L"},
{"^S#LS","L"},
{"^S#R#","R"},
{"^S#R*","R"},
{"^S#R@","R"},
{"^S#RS","R"},
{"^S#S#","S"},
{"^S#S*","S"},
{"^S#S@","S"},
{"^S#SS","S"},
{"^S#^#","B"},
{"^S#v#","#"},
{"^S*##","R"},
{"^S*L#","L"},
{"^S*R#","R"},
{"^S*S#","S"},
{"^S@##","R"},
{"^S@L#","L"},
{"^S@R#","R"},
{"^S@S#","S"},
{"^SB##","B"},
{"^SL##","L"},
{"^SR##","R"},
{"^SS##","S"},
{"^SSL#","L"},
{"^SSR#","R"},
{"^SSS#","S"},
{"^^>#<","@"},
{"^v#S#","S"},
{"^v#v<","<"},
{"^v>v#",">"},
{"v###*","R"},
{"v###B","B"},
{"v###L","L"},
{"v###R","R"},
{"v###S","S"},
{"v##*@","S"},
{"v##*L","L"},
{"v##*R","R"},
{"v##*S","S"},
{"v##@L","L"},
{"v##@R","R"},
{"v##@S","S"},
{"v##B#","*"},
{"v##B*","R"},
{"v##BB","B"},
{"v##BL","L"},
{"v##BR","R"},
{"v##BS","S"},
{"v##L#","*"},
{"v##L*","R"},
{"v##LB","B"},
{"v##LL","L"},
{"v##LR","R"},
{"v##LS","S"},
{"v##R#","*"},
{"v##R*","R"},
{"v##R@",">"},
{"v##RB","B"},
{"v##RL","L"},
{"v##RR","R"},
{"v##RS","S"},
{"v##S#","*"},
{"v##S*","R"},
{"v##S@","R"},
{"v##SB","B"},
{"v##SL","L"},
{"v##SR","R"},
{"v##SS","S"},
{"v#*##","L"},
{"v#*B#","L"},
{"v#*L#","L"},
{"v#*R#","L"},
{"v#*S#","L"},
{"v#>v<","@"},
{"v#@*#","S"},
{"v#@L#","<"},
{"v#@S#","L"},
{"v#B##","B"},
{"v#BB#","B"},
{"v#BL#","B"},
{"v#BR#","B"},
{"v#BS#","B"},
{"v#L##","L"},
{"v#L*#","L"},
{"v#L@#","L"},
{"v#LB#","L"},
{"v#LL#","L"},
{"v#LR#","L"},
{"v#LS#","L"},
{"v#R##","R"},
{"v#R*#","R"},
{"v#R@#","R"},
{"v#RB#","R"},
{"v#RL#","R"},
{"v#RR#","R"},
{"v#RS#","R"},
{"v#S##","S"},
{"v#S*#","S"},
{"v#S@#","S"},
{"v#SB#","S"},
{"v#SL#","S"},
{"v#SR#","S"},
{"v#SS#","S"},
{"v*###","S"},
{"v*#B#","S"},
{"v*#L#","S"},
{"v*#R#","S"},
{"v*#S#","S"},
{"v<###","S"},
{"v<#L#","S"},
{"v<#S#","S"},
{"v>###","S"},
{"v>#R#","S"},
{"v>#S#","S"},
{"v@##<","*"},
{"v@#*#","S"},
{"v@#S#","@"},
{"v@>##","*"},
{"vB###","B"},
{"vB#B#","B"},
{"vB#L#","B"},
{"vB#R#","B"},
{"vB#S#","B"},
{"vL###","L"},
{"vL#*#","L"},
{"vL#@#","L"},
{"vL#B#","L"},
{"vL#L#","L"},
{"vL#L@","L"},
{"vL#LS","L"},
{"vL#R#","L"},
{"vL#R@","L"},
{"vL#RS","L"},
{"vL#S#","L"},
{"vL#S*","L"},
{"vL#S@","L"},
{"vL#SS","L"},
{"vL*S#","L"},
{"vL@L#","L"},
{"vL@R#","L"},
{"vL@S#","L"},
{"vLSL#","L"},
{"vLSR#","L"},
{"vLSS#","L"},
{"vR###","R"},
{"vR#*#","R"},
{"vR#@#","R"},
{"vR#B#","R"},
{"vR#L#","R"},
{"vR#L@","R"},
{"vR#LS","R"},
{"vR#R#","R"},
{"vR#R@","R"},
{"vR#RS","R"},
{"vR#S#","R"},
{"vR#S*","R"},
{"vR#S@","R"},
{"vR#SS","R"},
{"vR*S#","R"},
{"vR@L#","R"},
{"vR@R#","R"},
{"vR@S#","R"},
{"vRSL#","R"},
{"vRSR#","R"},
{"vRSS#","R"},
{"vS###","S"},
{"vS#*#","S"},
{"vS#@#","S"},
{"vS#B#","S"},
{"vS#L#","S"},
{"vS#L@","S"},
{"vS#LS","S"},
{"vS#R#","S"},
{"vS#R@","S"},
{"vS#RS","S"},
{"vS#S#","S"},
{"vS#S*","S"},
{"vS#S@","S"},
{"vS#SS","S"},
{"vS#^#","S"},
{"vS*S#","S"},
{"vS@L#","S"},
{"vS@R#","S"},
{"vS@S#","S"},
{"vSSL#","S"},
{"vSSR#","S"},
{"vSSS#","S"},
{"v^#S#","#"},
{"v^#^<","<"},
{"v^>^#",">"},
{"vv###","B"},
{"vv#S#","B"}
  };


  public Cregles() {
  }
}